@@ -15,13 +15,18 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Operator for Telegram"""
-from typing import Optional
+"""Operator for Telegram."""
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.telegram.hooks.telegram import TelegramHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class TelegramOperator(BaseOperator):
     """
@@ -34,28 +39,23 @@ class TelegramOperator(BaseOperator):
         :ref:`howto/operator:TelegramOperator`
 
     :param telegram_conn_id: Telegram connection ID which its password is Telegram API token
-    :type telegram_conn_id: str
     :param token: Telegram API Token
-    :type token: str
     :param chat_id: Telegram chat ID for a chat/channel/group
-    :type chat_id: str
     :param text: Message to be sent on telegram
-    :type text: str
     :param telegram_kwargs: Extra args to be passed to telegram client
-    :type telegram_kwargs: dict
     """
 
-    template_fields = ('text', 'chat_id')
-    ui_color = '#FFBA40'
+    template_fields: Sequence[str] = ("text", "chat_id")
+    ui_color = "#FFBA40"
 
     def __init__(
         self,
         *,
         telegram_conn_id: str = "telegram_default",
-        token: Optional[str] = None,
-        chat_id: Optional[str] = None,
+        token: str | None = None,
+        chat_id: str | None = None,
         text: str = "No message has been set.",
-        telegram_kwargs: Optional[dict] = None,
+        telegram_kwargs: dict | None = None,
         **kwargs,
     ):
         self.chat_id = chat_id
@@ -70,10 +70,10 @@ class TelegramOperator(BaseOperator):
 
         super().__init__(**kwargs)
 
-    def execute(self, **kwargs) -> None:
-        """Calls the TelegramHook to post the provided Telegram message"""
+    def execute(self, context: Context) -> None:
+        """Calls the TelegramHook to post the provided Telegram message."""
         if self.text:
-            self.telegram_kwargs['text'] = self.text
+            self.telegram_kwargs["text"] = self.text
 
         telegram_hook = TelegramHook(
             telegram_conn_id=self.telegram_conn_id,
